@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Exporter 'import';
 
-our $VERSION = "0.01";
+our $VERSION = "0.011";
 
 our @EXPORT_OK = qw/hash_bulk_keycopy/;
 
@@ -24,14 +24,21 @@ Hash::BulkKeyCopy - a xs module for clone hash with keys
 
     use Hash::BulkKeyCopy;
 
+=head1 USAGE
+my $ht_ka = ["k1_1", "k1_2", "k1_3"];  
+my $hs_ka = ["k2_1", "k2_2", "k2_3"];  
+    
+my ($h1, $h2) = ({}, {"k2_1" => 1, "k2_2" => undef, "k2_3" => []});  
+hash_bulk_keycopy($h1, $h2, $ht_ka, $hs_ka);  
+
 =head1 DESCRIPTION
 
-Hash::BulkKeyCopy is a xs module for clone hash by a key arr.
+Hash::BulkKeyCopy is a xs module for clone hash by a key arr.  
 Double faster than PP source.
 
 =head1 LICENSE
 
-Copyright (C) itsusony.
+Copyright (C) itsusony. FreakOut.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
